@@ -47,7 +47,10 @@ setMethod(
     n.in.covered <- poss.distances$distance
     dist.data <- simulate.detections(poss.distances, population@detectability)
     dist.data <- rename.duplicates(dist.data)
-    dist.data <- dist.data[,c("object", "transect.ID", "distance", "x", "y")]  
+    # Get the covariate names
+    all.col.names <- names(object@population@population)
+    cov.param.names <- all.col.names[!all.col.names %in% c("object", "x", "y", "strata", "scale.param", "shape.param")]
+    dist.data <- dist.data[,c("object", "transect.ID", "distance", "x", "y", cov.param.names)]    
     # Check if we need to remove missing distances
     if(!is.null(point.transect@sampler.info$ac.simple)){
       # Remove distance for simple nodes
